<?php

namespace Drupal\content_snapshot\Converter;

use Drupal\content_snapshot\Encoder\YamlEncoderInterface;
use Drupal\content_snapshot\Normalizer\ContentSnapshotNormalizerContextTrait;
use Drupal\content_snapshot\Snapshot\SnapshotItemInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\Serializer\Normalizer\DenormalizerInterface;

/**
 * Converts snapshot item of a ContentEntity back into a ContentEntity.
 */
class ContentEntityToObjectConverter implements ToObjectConverterInterface {

  /**
   * Denormalizer.
   *
   * @var \Symfony\Component\Serializer\Normalizer\DenormalizerInterface
   */
  private $denormalizer;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private $entityTypeManager;

  /**
   * ContentEntityToObjectConverter constructor.
   *
   * @param \Symfony\Component\Serializer\Normalizer\DenormalizerInterface $denormalizer
   *   Denormalizer.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager.
   */
  public function __construct(
    DenormalizerInterface $denormalizer,
    EntityTypeManagerInterface $entityTypeManager,
  ) {
    $this->denormalizer = $denormalizer;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public function snapshotItemToObject(SnapshotItemInterface $snapshotItem) {
    $entityTypeId = $snapshotItem->getEntityType();
    $entityType = $this->entityTypeManager->getDefinition($entityTypeId);

    if (!$entityType) {
      return FALSE;
    }

    $class = $entityType->getClass();

    $context = [
      ContentSnapshotNormalizerContextTrait::$CONTENT_SNAPSHOT_CONTEXT => TRUE,
    ];

    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    return $this->denormalizer->denormalize($snapshotItem->toArray(), $class, YamlEncoderInterface::FORMAT, $context);
  }

}
