<?php

namespace Drupal\content_snapshot\Converter;

use Drupal\content_snapshot\Snapshot\SnapshotItemInterface;

/**
 * Chain of converters converting objects into snapshot items.
 */
class ToSnapshotItemConverterChain implements ToSnapshotItemConverterInterface {

  /**
   * Converters.
   *
   * @var \Drupal\content_snapshot\Converter\ToSnapshotItemConverterInterface[]
   */
  private $converters = [];

  /**
   * Add converter.
   *
   * @param \Drupal\content_snapshot\Converter\ToSnapshotItemConverterInterface $converter
   *   Converter.
   */
  public function addConverter(ToSnapshotItemConverterInterface $converter): void {
    $this->converters[] = $converter;
  }

  /**
   * {@inheritdoc}
   */
  public function arrayToSnapshot(array $content): ?SnapshotItemInterface {
    foreach ($this->converters as $converter) {
      if ($result = $converter->arrayToSnapshot($content)) {
        return $result;
      }
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function objectToSnapshot($object): ?SnapshotItemInterface {
    foreach ($this->converters as $converter) {
      if ($result = $converter->objectToSnapshot($object)) {
        return $result;
      }
    }

    return NULL;
  }

}
