<?php

namespace Drupal\content_snapshot\EventSubscriber;

use Drupal\content_snapshot\Event\SnapshotItemEvent;
use Drupal\content_snapshot\Snapshot\ContentEntitySnapshotItemInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class for UsersPrioritizerEventSubscriber.
 *
 * Users have to be imported first, or node's "owner" reference may get broken
 * if node is imported before its owner.
 * See: https://www.drupal.org/project/drupal/issues/2376999
 */
class UsersPrioritizerEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      SnapshotItemEvent::IMPORT_POST_CONVERTING => 'preImport',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function preImport(SnapshotItemEvent $contentSnapshotEvent) {
    $snapshotItem = $contentSnapshotEvent->getSnapshotItem();

    if (!$snapshotItem instanceof ContentEntitySnapshotItemInterface) {
      return;
    }

    if ($snapshotItem->getEntityType() !== 'user') {
      return;
    }

    $snapshotItem->setPriority(50);
  }

}
