<?php

namespace Drupal\content_snapshot\Normalizer;

use Drupal\content_snapshot\Encoder\YamlEncoderInterface;
use Drupal\serialization\Normalizer\FieldItemNormalizer;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Field\Plugin\Field\FieldType\PasswordItem;
use Drupal\pathauto\PathautoGeneratorInterface;

/**
 * Implements Class PasswordFieldItemNormalizer.
 */
class PasswordFieldItemNormalizer extends FieldItemNormalizer {

  use ContentSnapshotNormalizerContextTrait;

  /**
   * {@inheritdoc}
   */
  protected $format = YamlEncoderInterface::FORMAT;

  /**
   * {@inheritdoc}
   *
   * @deprecated in drupal:10.2.0 and is removed from drupal:11.0.0.
   *   Use getSupportedTypes() instead.
   * @see https://www.drupal.org/project/drupal/issues/3360124
   */
  protected $supportedInterfaceOrClass = PasswordItem::class;

  /**
   * Path auto generator.
   *
   * @var \Drupal\pathauto\PathautoGeneratorInterface|null
   */
  private $pathautoGenerator;

  /**
   * PathItemNormalizer constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Drupal\pathauto\PathautoGeneratorInterface $pathautoGenerator
   *   Path auto generator.
   */
  public function setPathautoGenerator(PathautoGeneratorInterface $pathautoGenerator) {
    $this->pathautoGenerator = $pathautoGenerator;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Drupal\Core\Field\FieldItemInterface $field
   *   Field.
   * @param string $format
   *   Format.
   * @param array $context
   *   Context.
   */
  public function normalize($field, $format = NULL, array $context = []):// phpcs:ignore Drupal.Commenting.FunctionComment.TypeHintMissing,Drupal.Files.LineLength.TooLong
  array|string|int|float|bool|\ArrayObject|NULL {

    $this->validateContext($context);

    $attributes = parent::normalize($field, $format, $context);
    $attributes['pre_hashed'] = TRUE;
    unset($attributes['existing']);

    return $attributes;
  }

  /**
   * {@inheritdoc}
   */
  public function denormalize($data, $class, $format = NULL, array $context = []): mixed {

    $this->validateContext($context);

    return parent::denormalize($data, $class, $format, $context);
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedTypes(?string $format): array {
    return [
      PasswordItem::class => TRUE,
    ];
  }

}
