<?php

namespace Drupal\content_snapshot\Normalizer\layout_builder;

use Drupal\content_snapshot\Encoder\YamlEncoderInterface;
use Drupal\content_snapshot\Normalizer\ContentSnapshotNormalizerContextTrait;
use Drupal\layout_builder\Plugin\DataType\SectionData;
use Drupal\layout_builder\Plugin\Field\FieldType\LayoutSectionItem;
use Drupal\serialization\Normalizer\FieldItemNormalizer;

/**
 * Normalizes layout builder's section.
 *
 * @internal
 */
class LayoutSectionItemNormalizer extends FieldItemNormalizer {

  use ContentSnapshotNormalizerContextTrait;

  /**
   * {@inheritdoc}
   */
  protected $format = YamlEncoderInterface::FORMAT;

  /**
   * {@inheritdoc}
   *
   * @deprecated in drupal:10.2.0 and is removed from drupal:11.0.0.
   *   Use getSupportedTypes() instead.
   * @see https://www.drupal.org/project/drupal/issues/3360124
   */
  protected $supportedInterfaceOrClass = LayoutSectionItem::class;

  /**
   * {@inheritdoc}
   */
  public function denormalize($data, $class, $format = NULL, array $context = []): mixed {

    $this->validateContext($context);

    /** @var \Drupal\layout_builder\Plugin\DataType\SectionData $section_data */
    $section_data = $this->serializer->denormalize($data['section'], SectionData::class, $format, $context);
    /** @var \Drupal\layout_builder\Plugin\Field\FieldType\LayoutSectionItem $target_instance */
    $target_instance = $context['target_instance'];
    $target_instance->setValue(['section' => $section_data->getValue()]);

    return $target_instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedTypes(?string $format): array {
    return [
      LayoutSectionItem::class => TRUE,
    ];
  }

}
