<?php

namespace Drupal\content_snapshot\Normalizer\layout_builder_st;

use Drupal\content_snapshot\Encoder\YamlEncoderInterface;
use Drupal\content_snapshot\Normalizer\ContentSnapshotNormalizerContextTrait;
use Drupal\layout_builder_st\Plugin\DataType\LayoutTranslationData;
use Drupal\serialization\Normalizer\TypedDataNormalizer;

/**
 * Implements Class LayoutTranslationDataNormalizer.
 */
class LayoutTranslationDataNormalizer extends TypedDataNormalizer {

  use ContentSnapshotNormalizerContextTrait;

  /**
   * {@inheritdoc}
   */
  protected $format = YamlEncoderInterface::FORMAT;

  /**
   * {@inheritdoc}
   *
   * @deprecated in drupal:10.2.0 and is removed from drupal:11.0.0.
   *   Use getSupportedTypes() instead.
   * @see https://www.drupal.org/project/drupal/issues/3360124
   * @phpstan-ignore class.notFound
   */
  protected $supportedInterfaceOrClass = LayoutTranslationData::class;

  /**
   * {@inheritdoc}
   */
  public function normalize($object, $format = NULL, array $context = []):// phpcs:ignore Drupal.Commenting.FunctionComment.TypeHintMissing,Drupal.Files.LineLength.TooLong
  array|\ArrayObject|bool|float|int|NULL|string {

    $this->validateContext($context);

    $normalized = parent::normalize($object, $format, $context);

    if (!empty($normalized['components'])) {
      foreach ($normalized['components'] as &$component) {
        // We cannot leave it here, because it can cause broken references on
        // translated pages after the import.
        unset($component['block_revision_id']);
      }
    }

    return $normalized;
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedTypes(?string $format): array {
    return [
      /* @phpstan-ignore class.notFound */
      LayoutTranslationData::class => TRUE,
    ];
  }

}
