<?php

namespace Drupal\content_snapshot\Snapshot;

/**
 * Class for EntitySnapshotItem.
 */
class EntitySnapshotItem extends SnapshotItem implements EntitySnapshotItemInterface {

  /**
   * Entity type.
   */
  private string $entityType;

  /**
   * Entity bundle.
   */
  private string $bundle;

  /**
   * Type of entity.
   */
  protected const TYPE = 'entity';

  /**
   * EntitySnapshotItem constructor.
   *
   * @param string $id
   *   Id of item.
   * @param string $getUuid
   *   Snapshot uuid.
   * @param array $data
   *   Snapshot data.
   * @param string $entityType
   *   Snapshot entity type.
   * @param string $bundle
   *   Snapshot entity bundle.
   */
  public function __construct(string $id, string $getUuid, array $data, string $entityType, string $bundle) {

    $this->entityType = $entityType;
    $this->bundle = $bundle;

    parent::__construct($id, $getUuid, $data);
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityType(): string {
    return $this->entityType;
  }

  /**
   * {@inheritdoc}
   */
  public function getBundle(): string {
    return $this->bundle;
  }

  /**
   * {@inheritdoc}
   */
  public function getPath(): ?string {
    return 'entity' . DIRECTORY_SEPARATOR . $this->getEntityType() . DIRECTORY_SEPARATOR . $this->getBundle();
  }

  /**
   * {@inheritdoc}
   *
   * @return self|null
   *   EntitySnapshotItem built from the given array.
   */
  public static function fromArray(array $array): ?SnapshotItemInterface {

    $type = self::extractTypeFromArray($array);

    if ($type !== static::TYPE) {
      return NULL;
    }

    $additionalMetadata = self::extractAdditionalMetadataFromArray($array);

    $id = self::extractIdFromArray($array);
    $hasUuid = self::extractUuidFromArray($array);

    $array = self::removeMetadataFromArray($array);

    $entity_type = $additionalMetadata['entity_type'];
    $bundle = $additionalMetadata['bundle'];

    return new self($id, $hasUuid, $array, $entity_type, $bundle);
  }

  /**
   * {@inheritdoc}
   */
  protected function getAdditionalMetadata(): array {
    return [
      'entity_type' => $this->getEntityType(),
      'bundle' => $this->getBundle(),
    ];
  }

}
