<?php

namespace Drupal\content_snapshot\Snapshot;

/**
 * Interface SnapshotItemInterface.
 *
 * Piece of content ready to be stored as a snapshot.
 */
interface SnapshotItemInterface {

  /**
   * This has to be a unique id.
   *
   * @return string
   *   Snapshot item's id.
   */
  public function getId(): string;

  /**
   * Item's UUID.
   *
   * @return string|null
   *   Snapshot item's UUID if available.
   */
  public function getUuid(): ?string;

  /**
   * Path in the snapshot structure.
   *
   * @return string
   *   Snapshot item's path in the snapshot's structure.
   */
  public function getPath(): ?string;

  /**
   * Returns content how it was originally normalized.
   *
   * @return array
   *   Normalized snapshot item's content.
   */
  public function getNormalizedContent(): array;

  /**
   * Sets priority used for ordering of items during the processing.
   *
   * @param int $priority
   *   Item's priority.
   */
  public function setPriority(int $priority);

  /**
   * Returns priority used in ordering.
   *
   * @return int
   *   Item's priority.
   */
  public function getPriority(): int;

  /**
   * Tells if item is excluded from the further processing.
   *
   * @return bool
   *   Is excluded?
   */
  public function isExcluded(): bool;

  /**
   * Function to set exclude item.
   *
   * @param bool $bool
   *   Set exclude item.
   */
  public function setExcluded(bool $bool): void;

  /**
   * Returns normalized content and additional metadata.
   *
   * @return array
   *   Normalized content with additional metadata.
   */
  public function toArray(): array;

}
