<?php

namespace Drupal\content_snapshot\StreamWrapper;

use Drupal\content_snapshot\Configuration\ConfigInterface;
use Drupal\Core\StreamWrapper\LocalStream;
use Drupal\Core\StreamWrapper\StreamWrapperInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a (content-snapshot://) stream wrapper class.
 */
class ContentSnapshotStream extends LocalStream {

  use StringTranslationTrait;

  public const STREAM_PATH = 'content-snapshot://';

  /**
   * Config Snapshot configuration.
   */
  private ConfigInterface $config;

  public function __construct(?ConfigInterface $config = NULL) {
    // @todo We need to handle situation when arguments are not provided
    //   because of this:
    //   https://www.drupal.org/project/drupal/issues/3504972#comment-15977292
    //   it can be changed if the core issue will be resolved.
    if (!$config) {
      $config = \Drupal::service('content_snapshot.config');
    }

    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public static function getType(): int {
    return StreamWrapperInterface::LOCAL_HIDDEN;
  }

  /**
   * {@inheritdoc}
   */
  public function getName(): string {
    return $this->t('Content snapshot files');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return $this->t('Content snapshot files');
  }

  /**
   * {@inheritdoc}
   */
  public function getDirectoryPath(): string {
    return $this->config->getSnapshotPath();
  }

  /**
   * {@inheritdoc}
   */
  public function getExternalUrl(): void {
    throw new \LogicException('Content snapshot files URL should not be public.');
  }

  /**
   * Create instance of the wrapper.
   */
  public static function create(ContainerInterface $container): static {
    return new self(
      $container->get('content_snapshot.config')
    );
  }

}
